import './App.css'
import { AnnoymousNickNameProvider } from './AuthorData';
import { CommentInput, CommentItem, CommentListContainer, CommentPagination, PostListControls, SubCommentData } from './Comment';
import CommentHeader from './CommentHeader';
import { Footer } from './Footer';
import { GalleryContent, GalleryContentHeader } from './Gallery';
import { GalleryTitleHeader } from './GalleryTitleHeader';
import { GlobalNavigationBar, Header, VisitHistory } from './Header';
import { LoginBox } from './Sidebar';
import { GalleryTable, TableRowData } from './table';
import { articles } from './data/article';
import { Route, Switch } from 'wouter';


const tableData: TableRowData[] = [
  { // Survey Example
    id: 2995,
    category: "설문",
    titleText: "어떤 상황이 와도 가족 안 굶길 것 같은 생활력 강해 보이는 스타는?",
    variant: "icon_survey",
    author: {
      type: "operator",
    },
    date: "25.03.24",
    views: "-",
    recommendations: "-",
    isAdOrSurvey: true,
  },
  { // AD Example
    id: 2996,
    category: "AD",
    titleText: "트릭컬 지금 접속 시 죠안 확정권 지급",
    variant: "icon_ad",
    author: {
      type: "operator",
    },
    date: "25.03.28",
    views: "-",
    recommendations: "-",
    isAdOrSurvey: true,
  },
  { // Notice Example 2
    id: 784571,
    category: "공지",
    titleText: "인방 떡밥은 별도의 갤러리를 이용해주세요",
    commentCount: 3,
    variant: "icon_notice",
    author: {
      type: "nickname",
      nickname: "ㅇㅇ",
      userType: "submanager", // Optional, if applicable
    },
    date: "25.03.08",
    views: 7018,
    recommendations: 6,
    isNotice: true,
  },
  ...articles.map((item) => ({
    id: item.id, // Random ID for each article
    category: "일반",
    titleText: item.Title,
    variant: "icon_pic",
    date: `25.04.02`,
    views: parseInt(item.View),
    commentCount: item.comments.length,
    author: item.Author.match(/ㅇㅇ \(\d+\.\d+\)/) ? {
      type: "IP",
      ip: item.Author.split(" ")[1],
    } : item.Author === "ㅇㅇ" ? {
      type: "semi-nickname",
      nickname: item.Author,
    } : {
      type: "nickname",
      nickname: item.Author,
    },
    titleLinkUrl: `/${item.id}`,
    recommendations: Math.floor(Math.random() * 50), // Random number for recommendations
    isNews: false,
  } satisfies TableRowData)),
  // ... Add all other rows from the original HTML here
  { // News Row Example
    id: '', // No ID
    category: "뉴스",
    titleText: "'2025 조치원 봄꽃축제' 개최 소식 밝혀",
    variant: "icon_dctrend",
    date: "18:00",
    views: "",
    recommendations: "",
    isNews: true,
  },
];

function GalleryMain() {
  return <AnnoymousNickNameProvider value="썬갤러">
    <Header />
    <GlobalNavigationBar />
    <VisitHistory recentVisits={[
      {
        id: 1,
        name: "워썬더",
        isMinor: true,
      },
      {
        id: 2,
        name: "배틀그라운드",
        isMinor: false,
      },
      {
        id: 3,
        name: "리그오브레전드",
        isMinor: false,
      },
      {
        id: 4,
        name: "발로란트",
        isMinor: false,
      },
      {
        id: 5,
        name: "오버워치",
        isMinor: true,
      }
    ]} />
    <div className='relative w-[1450px] mx-auto'>
      <main
        className='w-[1160px] m-[20px_auto_0]'
      >
        <section className='' >
          <div className='flex justify-between'>
            <div style={{
              width: "840px",
            }}>
              <GalleryTitleHeader title='워썬더 갤러리' />
              <div
                className='border-custom-blue-dark border w-[840px]'
              />
              <PostListControls owner />
              <GalleryTable data={tableData} />
              <PostListControls />
            </div>
            <div style={{
              width: "300px",
            }}>
              <LoginBox />
            </div>
          </div>
        </section>
      </main>
    </div>
    <Footer />
  </AnnoymousNickNameProvider>
}

function GalleryDetail(params: { id: string }) {
  const { id } = params;
  const idNumber = parseInt(id);
  const article = articles.find((item) => item.id === idNumber);
  if (!article) {
    return <div>Article not found</div>;
  }

  return (
    <AnnoymousNickNameProvider value="썬갤러">
      <div>
        <Header />
        <GlobalNavigationBar />
        <VisitHistory recentVisits={[
          {
            id: 1,
            name: "워썬더",
            isMinor: true,
          },
          {
            id: 2,
            name: "배틀그라운드",
            isMinor: false,
          },
          {
            id: 3,
            name: "리그오브레전드",
            isMinor: false,
          },
          {
            id: 4,
            name: "발로란트",
            isMinor: false,
          },
          {
            id: 5,
            name: "오버워치",
            isMinor: true,
          }
        ]} />
        <div className='relative w-[1450px] mx-auto'>
          <main
            className='w-[1160px] m-[20px_auto_0]'
          >
            <section className='' >
              <GalleryTitleHeader title='워썬더 갤러리' />
              <div
                className='border-custom-blue-dark border w-[1158px]'
              />
              <GalleryContentHeader kind='일반'
                title={article.Title}
                author={article.Author === "ㅇㅇ" ? {
                  type: "semi-nickname",
                  nickname: article.Author,
                } : article.Author.match(/ㅇㅇ \(\d+\)/) ? {
                  type: "IP",
                  ip: article.Author.split(" ")[1],
                } : {
                  type: "nickname",
                  nickname: article.Author,
                }}
                date='2025.02.04 21:32:47'
                views={parseInt(article.View)}
                recommendations={Math.floor(Math.random() * 50)}
                commentCount={article.comments.length}
              />
              <GalleryContent
                coverImage={`https://placehold.co/840x480?text=${encodeURIComponent(article.imageTitle)}`}
                coverImageAlt={`${article.imageTitle} (${article.imageDescription})`}
              >
                {article.body}
              </GalleryContent>
              <CommentHeader commentCount={9} />
              <CommentListContainer>
                {article.comments.map((comment, index) => (<CommentItem
                  key={index}
                  comment={{
                    id: index,
                    author: comment.nickname.match(/ㅇㅇ \(\d+\)/) ? {
                      type: "IP",
                      ip: comment.nickname.split(" ")[1],
                    } : comment.nickname === "ㅇㅇ" ? {
                      type: "semi-nickname",
                      nickname: comment.nickname,
                    } : {
                      type: "nickname",
                      nickname: comment.nickname,
                    },
                    text: comment.content,
                    timestamp: comment.date,
                  }}
                />))}
              </CommentListContainer>
              <CommentPagination currentPage={1} maxPage={2} />
              <CommentInput />
              <PostListControls owner />
              <div className='flex justify-between'>
                <div style={{
                  width: "840px",
                }}>
                  <GalleryTable data={tableData} />
                  <PostListControls />
                </div>
                <div style={{
                  width: "300px",
                }}>
                  <LoginBox />
                </div>
              </div>
            </section>
          </main>
        </div>
        <Footer />
      </div >
    </AnnoymousNickNameProvider>
  )
}

function App() {
  return <Switch>
    <Route path="/" component={GalleryMain} />
    <Route path="/:id" component={(params) => <GalleryDetail id={params.params.id} />} />
  </Switch>
}

export default App
