import { Separator } from "./Separator"
import { AuthorData, NickName } from './AuthorData';

export interface GalleryContentHeaderProps {
    title: string;
    kind: string;
    author: AuthorData;
    date: string;
    views?: number;
    recommendations?: number;
    /**
     * Number of comments on the post
     */
    commentCount?: number;
}

export function GalleryContentHeader({
    title,
    kind,
    author,
    date,
    views = 0,
    recommendations = 0,
    commentCount = 0,
}: GalleryContentHeaderProps) {
    return (
        <header>
            {/* Outer container with margin, padding, and bottom border */}
            <div className="mt-4 mb-[29px] pb-[11px] border-b border-solid border-gray-200">
                {/* Post Title */}
                <h3 className="px-0.5 mb-[7px] text-sm font-bold">
                    <span> [{kind}] </span>
                    <span>
                        {title}
                    </span>
                </h3>

                {/* Metadata container */}
                <div
                    className="relative text-[13px] cursor-pointer px-0.5 flex justify-between items-center"
                >
                    {/* Left section: Author, IP, Timestamp */}
                    <div>
                        <NickName author={author} />
                        <span className="cursor-default">
                            <Separator />
                            {date}
                        </span>
                    </div>

                    {/* Right section: Views, Recommends, Comments */}
                    <div
                        className="pr-[7px]"
                    >
                        <span className="cursor-default">
                            조회 {views}
                        </span>
                        <Separator />
                        <span className="cursor-default">
                            추천 {recommendations}
                        </span>
                        <Separator />
                        <span className="cursor-default">
                            {/* Comments link styled as a pill button */}
                            <a href="#" // Add appropriate link target
                                className="inline-block h-5 leading-5  px-2.5  bg-gray-200 
                             text-gray-700 border border-gray-300 rounded-full
                              hover:bg-gray-300 hover:border-gray-400 text-xs">
                                댓글 {commentCount}
                            </a>
                        </span>
                    </div>
                </div>
            </div>
        </header>
    );
}

interface GalleryRecommendationProps {
    recommendCount?: number;
    fixedNickCount?: number;
    downvoteCount?: number;
}

function GalleryRecommendation({ 
    recommendCount = 0, 
    fixedNickCount = 0, 
    downvoteCount = 0 
}: GalleryRecommendationProps) {
        return <div
                className="bg-white mx-auto mb-9 font-apple border border-[#c4c4c4] rounded-xs
                        pt-[19px] w-fit box-content">
                <div className="flex items-center justify-center overflow-hidden pb-2">
                        <div className="flex justify-end overflow-hidden w-[139px] mb-0.5">
                                <div className="text-custom-dropdown-text text-center pt-[10px] pl-[11px] w-[67px] font-bold">
                                        <p className="text-base leading-[22px] text-[#d31900] font-bold"
                                        >{recommendCount}</p>
                                        <p
                                                className="leading-3 flex items-end justify-center"
                                        >
                                                <span className="text-[16px]">
                                                        <img
                                                                className="align-middle inline-block"
                                                                src="/fix_nik.gif" alt="고정닉"
                                                        />
                                                        &nbsp;
                                                </span>
                                                <span className="text-custom-blue-dark text-[11px] font-normal">
                                                        {fixedNickCount}
                                                </span>
                                        </p>
                                </div>
                                <button
                                        className="font-apple text-[12px] cursor-pointer align-middle w-14"
                                >
                                        <em
                                                style={{
                                                        backgroundPositionX: "0px",
                                                        backgroundPositionY: "-315px",
                                                        width: "56px",
                                                        height: "56px",
                                                }}
                                                className="bg-sp-img inline-block"
                                        ></em>
                                </button>
                        </div>
                        <div
                                style={{
                                        width: "139px",
                                        marginBottom: "2px",
                                        display: "inline-block",
                                        marginLeft: "10px",
                                }}
                        >
                                <button
                                        style={{
                                                cursor: "pointer",
                                                verticalAlign: "middle",
                                                fontSize: "12px",
                                                float: "left",
                                                width: "56px",
                                        }}
                                        className="font-apple"
                                >
                                        <em
                                                style={{
                                                        backgroundImage:
                                                                'url("/sp_image.png")',
                                                        backgroundRepeat: "no-repeat",
                                                        backgroundPositionX: "0px",
                                                        backgroundPositionY: "-377px",
                                                        display: "inline-block",
                                                        width: "56px",
                                                        height: "56px",
                                                }}
                                        />
                                </button>
                                <div
                                        style={{
                                                float: "right",
                                                width: "64px",
                                                paddingTop: "17px",
                                                paddingRight: "12px",
                                                textAlign: "center",
                                                fontWeight: "bold",
                                                color: "rgb(85, 85, 85)",
                                                fontSize: "16px",
                                        }}
                                >
                                        <p> {downvoteCount} </p>
                                </div>
                        </div>
                </div>
                <div
                        className="flex items-center justify-center overflow-hidden h-9 relative
                        border-t border-[rgb(196,196,196)] divide-[rgb(196,196,196)] divide-x"
                >
                        <SilbechuButton />
                        <ShareButton />
                        <ReportButton />
                </div>
        </div>
}

function ReportButton() {
    return <button
        style={{
            backgroundColor: "rgb(249, 249, 249)",
            cursor: "pointer",
            verticalAlign: "middle",
            fontSize: "12px",
            width: "95px",
            height: "36px",
            marginLeft: "1px",
            color: "rgb(85, 85, 85)",
            textShadow: "rgb(255, 255, 255) 0px 1px",
            position: "relative"
        }}
    >
        <em
            style={{
                backgroundImage: 'url("/sp_image.png")',
                backgroundRepeat: "no-repeat",
                width: "18px",
                height: "20px",
                backgroundPosition: "-74px -241px",
                marginRight: "6px",
                verticalAlign: "-4px",
                display: "inline-block"
            }}
            className="inline-block"
        >
        </em>
        신고
    </button>;
}

function ShareButton() {
    return <button
        style={{
            backgroundColor: "rgb(249, 249, 249)",
            cursor: "pointer",
            verticalAlign: "middle",
            width: "96px",
            height: "36px",
            marginLeft: "1px",
            textShadow: "rgb(255, 255, 255) 0px 1px",
        }}
        className="align-middle relative cursor-pointer"
    >
        <em
            style={{
                backgroundPosition: "-74px -262px",
                width: "17px",
                height: "20px",
                marginRight: "6px",
                verticalAlign: "-4px",
            }}
            className="inline-block bg-sp-img"
        >
        </em>
        공유
    </button>;
}

function SilbechuButton() {
    return <button
        style={{
            backgroundColor: "rgb(249, 249, 249)",
            cursor: "pointer",
            verticalAlign: "middle",
            width: "95px",
            height: "36px",
            marginLeft: "1px",
            color: "rgb(85, 85, 85)",
            textShadow: "rgb(255, 255, 255) 0px 1px",
            position: "relative"
        }}
    >
        <em
            style={{
                width: "23px",
                height: "23px",
                backgroundPositionX: "-270px",
                backgroundPositionY: "-983px",
                marginRight: "3px",
                marginTop: "2px",
                verticalAlign: "-8px",
                display: "inline-block"
            }}
            className="bg-sp-img"
        >
        </em>
        실베추
    </button>;
}

interface GalleryContentProps {
    coverImage?: string;
    coverImageAlt?: string;

    children?: React.ReactNode;

    recommendCount?: number;
    fixedNickCount?: number;
    downvoteCount?: number;
}

export function GalleryContent({
    coverImage,
    children,
    recommendCount = 0,
    fixedNickCount = 0,
    downvoteCount = 0,
    coverImageAlt = "cover image",
}: GalleryContentProps) {
    return <article
        className="text-custom-gray-dark text-[13px] font-apple"
    >
        <div style={{ lineHeight: "22px" }}>
            <div style={{ marginBottom: "50px" }}>
                <div className="overflow-hidden relative">
                    <div>
                        <span className="ml-[10px]">
                            <img
                                style={{
                                    maxWidth: "100%",
                                    width: "550px",
                                    height: "350px",
                                }}
                                alt={coverImageAlt}
                                src={coverImage}
                            />
                        </span>
                    </div>
                    <pre />
                    <div
                        style={{
                            width: "900px",
                        }}
                    >
                        {children}
                    </div>
                </div>
            </div>
            <div className="relative">
                <GalleryRecommendation
                    recommendCount={recommendCount}
                    fixedNickCount={fixedNickCount}
                    downvoteCount={downvoteCount}
                />
            </div>
            <div
                className="w-full overflow-hidden text-center mt-2"
            />
            <div
                className="w-[728px] mt-[20px] mx-auto"
            />
        </div>
    </article>
}